@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '2.06_01'; # TRIAL VERSION
+our $VERSION = '2.08_01'; # TRIAL VERSION
 
 use parent 'Exporter';
 use Test::Builder;
@@ -74,6 +74,11 @@ my %versions;
 my $test = Test::Builder->new;
 
 our $_IN_VERSION_ALL_OK = 0;
+our %FILE_FIND_RULE_EXTRAS = (
+  untaint => 1,
+  ($^O eq 'MSWin32' ? (untaint_pattern => qr|^(([a-zA-Z]:)?[-+@\w./]+)$|x) : ()),
+);
+
 
 sub version_ok {
   my ( $file, $name ) = @_;
@@ -211,7 +216,7 @@ sub version_all_ok {
 
   $name ||= "all modules in $dir have valid versions";
 
-  my @files = File::Find::Rule->perl_module->extras( { untaint => 1 } )->in($dir);
+  my @files = File::Find::Rule->perl_module->extras(\%FILE_FIND_RULE_EXTRAS)->in($dir);
 
   {
     local $_IN_VERSION_ALL_OK = 1;
@@ -262,7 +267,7 @@ Test::Version - Check to see that version's in modules are sane
 
 =head1 VERSION
 
-version 2.06_01
+version 2.08_01
 
 =head1 SYNOPSIS
 
@@ -480,7 +485,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2017 by Caleb Cushing.
+This software is Copyright (c) 2018 by Caleb Cushing.
 
 This is free software, licensed under:
 
